pub struct SpellTargetSelfServerPacket {
pub player_id: i32,
pub spell_id: i32,
pub spell_heal_hp: i32,
pub hp_percentage: i32,
pub hp: Option<i32>,
pub tp: Option<i32>,
}Expand description
Nearby player self-casted a spell
Fields
player_id: i32spell_id: i32spell_heal_hp: i32hp_percentage: i32hp: Option<i32>The official client reads this if the packet is larger than 12 bytes
tp: Option<i32>The official client reads this if the packet is larger than 12 bytes
Implementations